pg.ddx.io pgsql-hackers@postgresql.org mailing list archive
help / color / mirror / Atom feed From: Tom Lane <tgl@sss.pgh.pa.us>
To: Heikki Linnakangas <hlinnaka@iki.fi>
Cc: Alexander Lakhin <exclusion@gmail.com>
Cc: Thomas Munro <thomas.munro@gmail.com>
Cc: Tomas Vondra <tomas.vondra@enterprisedb.com>
Cc: Ronan Dunklau <ronan.dunklau@aiven.io>
Cc: PostgreSQL Hackers <pgsql-hackers@lists.postgresql.org>
Subject: Re: Failures in constraints regression test, "read only 0 of 8192 bytes"
Date: Thu, 20 Jun 2024 19:12:22 -0400
Message-ID: <487327.1718925142@sss.pgh.pa.us> (raw )
In-Reply-To: <680fafbe-3422-457d-95c2-90f9aa9ac592@iki.fi >
References: <CA+hUKGK+5DOmLaBp3Z7C4S-Yv6yoROvr1UncjH2S1ZbPT8D+Zg@mail.gmail.com >
<e4f94648-4236-4358-b64c-6a935e33658d@enterprisedb.com >
<2185821.Icojqenx9y@aivenlaptop >
<5c5a0015-723a-4fa7-85d5-2f0f47b92094@enterprisedb.com >
<CA+hUKGJvFgkEgbKyPZj4CwjN9=A+ggio3_2xdwnK0Gd8RzAYuw@mail.gmail.com >
<deefcee6-c8bb-40ed-a4e5-6c20648cf043@enterprisedb.com >
<61ef0b89-1ec6-4d88-afbd-2ffc2c977511@enterprisedb.com >
<CA+hUKGKKQJRap2M5EE7XoQRn5-O0h1=p0wkpkGog=87me-g6+g@mail.gmail.com >
<05fd672f-2eac-4758-91e9-fa7afafa147e@enterprisedb.com >
<CA+hUKGKdOS9xccxast-L-MLN3=yA0TYpm=cRhpo_FCq6+O-jQA@mail.gmail.com >
<CA+hUKG+XOrCi3UwiK5dNL_B8Eav6hMk334L4Qpctfw4MPDUYaw@mail.gmail.com >
<CA+hUKGL0dBL-+0_GoN9H_9s0Fx3iOQu28D7Y5o=W0QyP2+s8iQ@mail.gmail.com >
<de4070e3-d468-4284-a778-8b8025db41f1@iki.fi >
<50ebc494-0d52-4b76-bea4-f7ab5569300a@iki.fi >
<CA+hUKGJU1hb2jZQWEDniUEU2E1sz_8gUhccg7+Uj0kzBeSCPJA@mail.gmail.com >
<e9847a44-8f69-483f-92dc-5a2ca0a8be59@iki.fi >
<987b1c8c-8c91-4847-ca0e-879f421680ff@gmail! .com >
<680fafbe-3422-457d-95c2-90f9aa9ac592@iki.fi >
Heikki Linnakangas <hlinnaka@iki.fi> writes:
> In commit af0e7deb4a, I removed the call to RelationCloseSmgr() from
> RelationCacheInvalidate(). I thought it was no longer needed, because we
> no longer free the underlying SmgrRelation.
> However, it meant that if the relfilenode of the relation was changed,
> the relation keeps pointing to the SMgrRelation of the old relfilenode.
> So we still need the RelationCloseSmgr() call, in case the relfilenode
> has changed.
Ouch. How come we did not see this immediately in testing? I'd have
thought surely such a bug would be exposed by any command that
rewrites a heap.
regards, tom lane
view thread (24+ messages) latest in thread
Message-ID: <487327.1718925142@sss.pgh.pa.us>
Permalink: ../487327.1718925142@sss.pgh.pa.us/
Also on: postgresql.org/message-id/487327.1718925142@sss.pgh.pa.us
copy link · copy postgr.es
reply Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Reply to all the recipients using the --to and --cc options:
reply via email
To: pgsql-hackers@postgresql.org
Cc: tgl@sss.pgh.pa.us, hlinnaka@iki.fi, exclusion@gmail.com, thomas.munro@gmail.com, tomas.vondra@enterprisedb.com, ronan.dunklau@aiven.io, pgsql-hackers@lists.postgresql.org
Subject: Re: Failures in constraints regression test, "read only 0 of 8192 bytes"
In-Reply-To: <487327.1718925142@sss.pgh.pa.us>
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
This inbox is served by DDX for PostgreSQL; see mirroring instructions
for how to clone and mirror all data and code used for this inbox